@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package asn1
@@ -77,10 +72,10 @@ func (c *Encoder) WriteRequest(path []int, tag string, cmd int) error {
 // WriteUniversal writes the provided integer into the buffer as an glow encoded universal value.
 func (c *Encoder) WriteUniversal(path []int) {
 	c.data.WriteByte(UniversalObjectTag)
-	c.data.WriteByte(byte((len(path))))
+	c.data.WriteByte(uint8(len(path)))
 
 	for _, p := range path {
-		c.data.WriteByte(byte((p)))
+		c.data.WriteByte(uint8(p))
 	}
 }
 
@@ -135,7 +130,7 @@ func (c *Encoder) writeInt(i int, cont uint8) error {
 		return errs.Wrap(err, "failed native go int asn1 marshal")
 	}
 
-	c.data.WriteByte(byte(len(b)))
+	c.data.WriteByte(uint8(len(b)))
 	c.data.Write(b)
 
 	return nil
