@@ -17,9 +17,13 @@ package s101
 const (
 	// FirstMultiPacket is byte to identify a multilayer packet in S101.
 	FirstMultiPacket = 0x80
-
+	// BodyMultiPacket is byte to identify a packet in a multilayer packet message in S101.
+	BodyMultiPacket = 0x00
 	// LastMultiPacket is byte to identify end of a multilayer packet in S101.
-	lastMultiPacket = 0x40
+	LastMultiPacket = 0x40
+	// SinglePacket is byte to identify a single packet message in S101.
+	SinglePacket = 0xC0
+
 	// BOF S101 packet opening byte.
 	bof = 0xfe
 	// Slot S101 packet Slot byte.
@@ -51,10 +55,10 @@ const (
 
 	// s101LenTilGlow is offset for how many S101 bytes it takes to get till Glow payload.
 	s101LenTilGlow = 10
+	// s101LenAfterGlow is offset for how many S101 bytes follow Glow payload till EOF.
+	s101LenAfterGlow = 3
 	// checkSumSecondDeviation is byte used in CRC calculations based on ember+ documentation.
 	checkSumSecondDeviation = 8
-	// byteSkip used to indicate when byte is required to be skipped in different ways.
-	byteSkip = 1
 )
 
 //nolint:gochecknoglobals
